% steerpatches : apply group of steering matrices to a group of patches
%
% tpatches=steerpatches(patches,steermat)
%
% Inputs:
% patches - pd x pd x Npatches x nbands array of input patches
% steermat - nbands x nbands x Npatches array of steering matrices
%
% Outputs:
% tpatches - pd x pd x Npatches x nbands array of transformed patches
function tpatches=steerpatches(patches,steermat)
tpatches = zeros(size(patches));
s=size(patches);
nbands = size(patches,4);
s1ones = ones(1,s(1));
s2ones = ones(1,s(2));
% this is essentially matrix multiplication by steermat, but with a
% different matrix along each entry of Npatches dimension
for m = 1:nbands
  tp_temp = zeros(s(1:3));
  for n=1:nbands
    steermat_mn = steermat(m,n,:);
    tp_temp=tp_temp + patches(:,:,:,n).*steermat_mn(s1ones,s2ones,:);
  end
  tpatches(:,:,:,m)=tp_temp;
end
